UHHformats: R Markdown/Quarto templates designed for the University of Hamburg
Source:R/UHHformats.R
UHHformats-package.RdA package for creating HTML, PDF and Microsoft Word documents, reports, and cheat sheets using either R Markdown or now also Quarto.
Quarto templates
The following templates can be created using the function create_quarto_doc.
Simply set the template argument to one of the following types:
'html_doc': Creates a simple HTML document with a fixed navigation bar on the left side.
'word_doc': Creates a simple MS Word document in English (default) and German.
'pdf_doc': Creates a simple PDF/LaTeX document in English (default) and German.
'pdf_report': Creates a report-like PDF/LaTeX document in English (default) and German.
'pdf_cheatsheet': Creates a landscape PDF cheatsheet with configurable multi-column layout and colored textboxes.
R Markdown templates
The following templates can be created using RStudio's IDE or by using the
function create_rmd_doc:
html_doc: Creates a simple HTML document with a fixed table of content.word_doc: Creates a simple MS Word document in English (default) and German.pdf_doc: Creates a simple PDF/LaTeX document in English (default) and German.pdf_report: Creates a report-like PDF/LaTeX document in English (default) and German.pdf_cheatsheet: Creates a simple PDF cheatsheet with box layouts.
Author
Maintainer: Saskia Otto saskia.a.otto@gmail.com (ORCID)