create_rmd_doc creates a new subdirectory inside the current directory, which will
contain the ready-to-use R Markdown file and all associated files.
Details
The function is a modified version of the create.doc function in the
rmdformats package.
See also
create_quarto_doc for Quarto templates.
Examples
if (FALSE) { # \dontrun{
# Create template for a simple HTML document
create_rmd_doc("my_html_doc", template = "html_doc")
# Create template for a PDF report document
create_rmd_doc("my_report", template = "pdf_report")
# Create in a specific directory
create_rmd_doc("my_doc", template = "pdf_doc", path = "~/Documents")
} # }